<?php

namespace Toalett\Redis\Timeseries\Protocol\Query\Components;

use Toalett\Redis\Timeseries\Exception\InvalidArgumentException;
use Toalett\Redis\Timeseries\Model\Filter;

trait ContainsFilters
{
    /** @var Filter[] */
    protected array $filters = [];

    public function __construct(Filter...$filters)
    {
        $this->filters = $filters;
    }

    /**
     * @param Filter ...$filters
     * @return $this
     */
    public function filter(Filter $filter): self
    {
        $this->filters[] = $filter;
        return $this;
    }

    protected function appendFilters(array $command): array
    {
        if (empty($this->filters)) {
            throw new InvalidArgumentException('At least one filter is required');
        }

        $command[] = 'FILTER';
        foreach ($this->filters as $filter) {
            $command[] = $filter->toString();
        }

        return $command;
    }
}
